@@ -408,6 +408,7 @@ impl From<TransactionTokenBalance> for generated::TokenBalance {
                 amount: value.ui_token_amount.amount,
                 ui_amount_string: value.ui_token_amount.ui_amount_string,
             }),
+            owner: value.owner,
         }
     }
 }
@@ -435,6 +436,7 @@ impl From<generated::TokenBalance> for TransactionTokenBalance {
                     )
                 },
             },
+            owner: value.owner,
         }
     }
 }
@@ -548,6 +550,9 @@ impl TryFrom<tx_by_addr::TransactionError> for TransactionError {
             14 => TransactionError::SanitizeFailure,
             15 => TransactionError::ClusterMaintenance,
             16 => TransactionError::AccountBorrowOutstanding,
+            17 => TransactionError::WouldExceedMaxBlockCostLimit,
+            18 => TransactionError::UnsupportedVersion,
+            19 => TransactionError::InvalidWritableAccount,
             _ => return Err("Invalid TransactionError"),
         })
     }
@@ -606,6 +611,15 @@ impl From<TransactionError> for tx_by_addr::TransactionError {
                 TransactionError::AccountBorrowOutstanding => {
                     tx_by_addr::TransactionErrorType::AccountBorrowOutstandingTx
                 }
+                TransactionError::WouldExceedMaxBlockCostLimit => {
+                    tx_by_addr::TransactionErrorType::WouldExceedMaxBlockCostLimit
+                }
+                TransactionError::UnsupportedVersion => {
+                    tx_by_addr::TransactionErrorType::UnsupportedVersion
+                }
+                TransactionError::InvalidWritableAccount => {
+                    tx_by_addr::TransactionErrorType::InvalidWritableAccount
+                }
             } as i32,
             instruction_error: match transaction_error {
                 TransactionError::InstructionError(index, ref instruction_error) => {
